@@ -19,11 +19,11 @@ $Net::OAuth::PROTOCOL_VERSION = Net::OAuth::PROTOCOL_VERSION_1_0A;
 
 =head1 NAME
 
-Net::Xero - The great new Net::Xero!
+Net::Xero - Interface to Xero accounting
 
 =head1 VERSION
 
-Version 0.20.20
+Version 0.40
 
 =cut
 
@@ -395,7 +395,7 @@ sub _talk {
     my $request     = Net::OAuth->request("protected resource")->new(%opts);
     my $private_key = Crypt::OpenSSL::RSA->new_private_key($self->cert);
     $request->sign($private_key);
-    #my $req = HTTP::Request->new($method, $request->to_url);
+    #my $req = HTTP::Request->new($method, $request->to_url);
     my $req = HTTP::Request->new($method, $request_url);
     if ($hash and ($method eq 'POST')) {
         $req->content($request->to_post_body);
